@@ -37,10 +37,16 @@ void PrintUsage(char *name, int iarg, char *arg)
            "      -Si bozol1 <0/1> : supress/enable bozo L1 defaults\n");
    fprintf(stderr,
            "      -Si archdef <1/0> : enable/supress arch default use\n");
+   fprintf(stderr,
+"      -Si ieee <1/0> : dis/allow optimizations that break IEEE FP standard\n");
+   fprintf(stderr,
+           "          (eg., NEON, 3DNow!)\n");
    fprintf(stderr,
            "      -Si latune <1/0> : do/don't tune F77 LAPACK routines\n");
       fprintf(stderr,
         "      -Si nof77 <0/1> : Have/don't have fortran compiler\n");
+      fprintf(stderr,
+           "   -tl <#> <list> : set # of threads, use list of affinity IDs\n");
       fprintf(stderr,
         "      -Si omp <0/1> : don'tuse/use OpenMP for threading\n");
       fprintf(stderr,
@@ -50,6 +56,8 @@ void PrintUsage(char *name, int iarg, char *arg)
       fprintf(stderr, "                           to $BLDdir/src/lapack/ref\n");
    fprintf(stderr,
         "      -Ss kern <path/to/comp> : use comp for all kernel compilers\n");
+   fprintf(stderr,
+      "      -Ss ADdir <path/to/archdefs> : Get archdefs frm custom path\n");
    fprintf(stderr,
         "      -Ss pmake <parallel make invocation (eg '$(MAKE) -j 4')>\n");
    fprintf(stderr,
@@ -72,6 +80,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
               int *mhz,                /* Clock rate in Mhz */
               int *ptrbits             /* # of bits in ptr: 32/64 */,
               int *nthreads,           /* # of threads */
+              int **tids,              /* thread affinity ID list */
               int *omp,                /* Build OpenMP version of threading? */
               int *AntThr,             /* Build Antoine's threads? */
               char **comps,
@@ -81,6 +90,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
               char **bindir,          /* path to top of binary directory */
               int *bozol1,            /* Use untuned L1 */
               int *UseArchDef,        /* Use arch defaults */
+              int *IEEE,              /* enforce IEEE FP standard? */
               int *latune,            /* Tune LAPACK? */
               int *NoF77,
               int *lapackref,
@@ -91,6 +101,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
               char **smaflags,       /* single prec muladd flags */
               char **dmaflags,       /* double prec muladd flags */
               char **f77lib,         /* netlib F77 LAPACK  */
+              char **ADd,            /* ArchDef directory */
               int *flush,             /* size in KB to flush */
               char **targ             /* mach to ssh to*/
              )
@@ -102,9 +113,10 @@ void GetFlags(int nargs,                /* nargs as passed into main */
    char ln[1024];
 
    *verb = 0;
+   *ADd = NULL;
    *srcdir = *bindir = NULL;
     *bozol1 = 0;
-    *latune = *UseArchDef = 1;
+    *IEEE = *latune = *UseArchDef = 1;
     *flapack = NULL;
     *f77lib = NULL;
     *smaflags = *dmaflags = NULL;
@@ -116,7 +128,6 @@ void GetFlags(int nargs,                /* nargs as passed into main */
    *gccflags = NULL;
 
    *flush = 0;
-   *nthreads = 0;
    *ptrbits = 0;
    *mhz = 0;
    *mach = 0;
@@ -126,6 +137,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
    *verb = 0;
    *NoF77 = 0;
    *nthreads = -1;
+   *tids = NULL;
    *omp = *AntThr = 0;
    *pmake = NULL;
    for (i=1; i < nargs; i++)
@@ -134,15 +146,26 @@ void GetFlags(int nargs,                /* nargs as passed into main */
          PrintUsage(args[0], i, args[i]);
       switch(args[i][1])
       {
-      case 'f':
-         if (++i >= nargs)
-            PrintUsage(args[0], i, "out of arguments");
-         *flush = atoi(args[i]);
-         break;
       case 't':
          if (++i >= nargs)
             PrintUsage(args[0], i, "out of arguments");
          *nthreads = atoi(args[i]);
+         if (args[i-1][2] == 'l')
+         {
+            *tids = malloc(*nthreads * sizeof(int));
+            assert(*tids);
+            for (k=0; k < *nthreads; k++)
+            {
+               if (++i >= nargs)
+                  PrintUsage(args[0], i, "out of arguments");
+               (*tids)[k] = atoi(args[i]);
+            }
+         }
+         break;
+      case 'f':
+         if (++i >= nargs)
+            PrintUsage(args[0], i, "out of arguments");
+         *flush = atoi(args[i]);
          break;
       case 'b':
          if (++i >= nargs)
@@ -196,9 +219,11 @@ void GetFlags(int nargs,                /* nargs as passed into main */
          if (DoInt)
             k = atoi(args[i]);
          else
-            sp = args[i];
+            sp = NewStringCopy(args[i]);
          if (!strcmp(sp0, "archdef"))
             *UseArchDef = k;
+         else if (!strcmp(sp0, "ieee"))
+            *IEEE = k;
          else if (!strcmp(sp0, "bozol1"))
             *bozol1 = k;
          else if (!strcmp(sp0, "latune"))
@@ -213,6 +238,8 @@ void GetFlags(int nargs,                /* nargs as passed into main */
             *NoF77 = k;
          else if (!strcmp(sp0, "kern"))
             gcc3 = sp;
+         else if (!strcmp(sp0, "ADdir") || !strcmp(sp0, "addir"))
+            *ADd = sp;
          else if (!strcmp(sp0, "pmake"))
             *pmake = sp;
         else if (!strcmp(sp0, "flapack"))
@@ -259,6 +286,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
          sp = args[i];
          k = -1;
          if (*sp == 'i' && sp[1] == 'c') k = ICC_;
+         else if (*sp == 'g' && sp[1] == 'c') k = GCC_;
          else if (*sp == 'i' && sp[1] == 'f') k = F77_;
          else if (*sp == 's' && sp[1] == 'k') k = SKC_;
          else if (*sp == 'd' && sp[1] == 'k') k = DKC_;
@@ -267,6 +295,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
          else if (*sp == 'x' && sp[1] == 'c') k = XCC_;
          if (*sp == 'a' && (sp[1] == 'l' || sp[1] == 'c'))
          {  /* only appended flags can be applied to all compilers */
+            const int SKIPGCC=(sp[2] != 'g'), SKIPF=(sp[1] == 'c');
             if (args[i-1][1] == 'F')
             {
                if (args[i-1][2] == 'a')
@@ -288,7 +317,7 @@ void GetFlags(int nargs,                /* nargs as passed into main */
             if (++i >= nargs)
                PrintUsage(args[0], i, "out of arguments");
             for (k=k0; k < kn; k++)
-               if (sp[1] == 'l' || k-2*NCOMP != F77_)
+               if ((!SKIPF || k-k0 != F77_) && (!SKIPGCC || k-k0 != GCC_))
                   comps[k] = args[i];
             if (sp[2] == 'g' && args[i-2][1] == 'F')
                *gccflags = args[i];
@@ -364,6 +393,8 @@ char *GetPtrbitsFlag(enum OSTYPE OS, enum MACHTYPE arch, int ptrbits,
       return(sp);
    if (MachIsMIPS(arch))
       return((ptrbits == 64) ? "-mabi=64" : "-mabi=n32");
+   if (MachIsS390(arch))
+      return((ptrbits == 64) ? "-m64" : "-m31");
    if (!CompIsGcc(comp))
    {
 /*
@@ -388,11 +419,11 @@ char *GetPtrbitsFlag(enum OSTYPE OS, enum MACHTYPE arch, int ptrbits,
    else if (OS == OSAIX)
       sp = (ptrbits == 64) ? "-maix64" : "-maix32";
    else if ((MachIsX86(arch) || MachIsPPC(arch) || MachIsUS(arch)) ||
-            arch == IbmPwr7 || arch == IbmPwr6)
+            arch == IbmPwr7 || arch == IbmPwr6 || arch == Pwre6500)
    {
       if (ptrbits == 64)
          sp = "-m64";
-       else if (ptrbits == 32)
+      else if (ptrbits == 32)
          sp = "-m32";
    }
    return(sp);
@@ -409,10 +440,11 @@ int main(int nargs, char **args)
    int THREADS=0;
    int Use3DNow=0;  /* this needs to come from getflags */
    int ncpu, omp, AntThr, lapackref;
-   int USEDEFL1, USEARCHDEF, LATUNE;
+   int USEDEFL1, USEARCHDEF, LATUNE, USEIEEE, USEMINGW;
+   int *tids;
    #define NPREC 4
    char pres[NPREC] = {'s', 'd', 'c', 'z'};
-   char *targ, *sp, *pmake, *flapack;
+   char *targ, *sp, *pmake, *flapack, *ADd;
    char *comps[3*NCOMP], *comp, *flags, *srcdir, *blddir, *f2cdefs, *cdefs;
    char *outfile, *smaflags, *dmaflags, *f77lib, *gccflags, *goodgcc;
    char targarg[256], ln[1024];
@@ -420,10 +452,10 @@ int main(int nargs, char **args)
    char *adnames[NARDEF] = {"sKERNDEF", "dKERNDEF", "sMMDEF", "dMMDEF"};
 
    GetFlags(nargs, args, &verb, &OS, (enum ASMDIA*) &asmb, &vecexts, &mach,
-            &mhz, &ptrbits, &ncpu, &omp, &AntThr, comps, &gccflags, &outfile,
-            &srcdir, &blddir, &USEDEFL1, &USEARCHDEF, &LATUNE, &nof77,
-            &lapackref, &f2cdefs, &cdefs, &pmake, &flapack,
-            &smaflags, &dmaflags, &f77lib, &l2size, &targ);
+            &mhz, &ptrbits, &ncpu, &tids, &omp, &AntThr, comps, &gccflags,
+            &outfile, &srcdir, &blddir, &USEDEFL1, &USEARCHDEF, &USEIEEE,
+            &LATUNE, &nof77, &lapackref, &f2cdefs, &cdefs, &pmake, &flapack,
+            &smaflags, &dmaflags, &f77lib, &ADd, &l2size, &targ);
    if (ncpu > 1) THREADS = 1;
    if (!outfile)
       fpout = stdout;
@@ -479,6 +511,7 @@ int main(int nargs, char **args)
       if (!comps[NCOMP+i])
          comps[NCOMP+i] = comps[NCOMP+k];
    }
+   USEMINGW = (OSIsWin(OS) && strstr(comps[GCC_], "mgwgcc"));
 /*
  * If F77 compiler unspecified or nof77 asserted, set it to ICC for linking
  */
@@ -496,7 +529,7 @@ int main(int nargs, char **args)
          ISAX = i;
 
    fprintf(fpout, "#  ----------------------------\n");
-   fprintf(fpout, "#  Make.inc for ATLAS3.9.51\n");
+   fprintf(fpout, "#  Make.inc for ATLAS3.10.2\n");
    fprintf(fpout, "#  ----------------------------\n\n");
 
    fprintf(fpout, "#  ----------------------------------\n");
@@ -511,6 +544,8 @@ int main(int nargs, char **args)
    fprintf(fpout, "%d", ptrbits);
    if (ISAX)
       fprintf(fpout, "%s", ISAXNAM[ISAX]);
+   if (!USEIEEE)
+      fprintf(fpout, "NONIEEE");
    fprintf(fpout, "\n\n");
 
    fprintf(fpout, "#  ----------------------------\n");
@@ -533,13 +568,16 @@ int main(int nargs, char **args)
    fprintf(fpout, "   AUXdir = $(BLDdir)/src/auxil\n");
    fprintf(fpout, "   CBLdir = $(BLDdir)/interfaces/blas/C/src\n");
    fprintf(fpout, "   FBLdir = $(BLDdir)/interfaces/blas/F77/src\n");
-   fprintf(fpout, "   PTSdir = $(BLDdir)/src/pthreads\n");
    fprintf(fpout, "   MMTdir = $(BLDdir)/tune/blas/gemm\n");
    fprintf(fpout, "   MVTdir = $(BLDdir)/tune/blas/gemv\n");
    fprintf(fpout, "   R1Tdir = $(BLDdir)/tune/blas/ger\n");
    fprintf(fpout, "   L1Tdir = $(BLDdir)/tune/blas/level1\n");
    fprintf(fpout, "   L3Tdir = $(BLDdir)/tune/blas/level3\n");
    fprintf(fpout, "   FLAdir = $(BLDdir)/src/lapack/reference\n");
+   if (ADd)
+      fprintf(fpout, "   ADdir  = %s\n", ADd);
+   else
+      fprintf(fpout, "   ADdir  = $(SRCdir)/CONFIG/ARCHS\n");
    fprintf(fpout, "\n");
 
    fprintf(fpout,
@@ -614,6 +652,16 @@ int main(int nargs, char **args)
         !CompIsAppleGcc(comps[DMC_]))
       fprintf(fpout, " -DATL_AVgcc");
    fprintf(fpout, "\n\n");
+   if (tids)
+   {
+      int k;
+      fprintf(fpout, "   TIDLIST= -tl %d", ncpu);
+      for (k=0; k < ncpu; k++)
+         fprintf(fpout, " %d", tids[k]);
+   }
+   else
+      fprintf(fpout, "TIDLIST=");
+   fprintf(fpout, "\n\n");
 
    fprintf(fpout,
    "#  -------------------------------------------------------------------\n");
@@ -631,6 +679,18 @@ int main(int nargs, char **args)
    DisplayFile(ln, fpout, 0);
    fprintf(fpout, "   NPROC=%d\n", ncpu);
    fprintf(fpout, "   CDEFS = $(L2SIZE) $(INCLUDES) $(F2CDEFS) $(ARCHDEFS)");
+   if (!USEIEEE)
+      fprintf(fpout, " -DATL_NONIEEE=1");
+/*
+ * Dump -m32/-m64 to CDEFS if it is in normal flags, so that generic flags
+ * given in index files will still work.  If the user mixes gcc which mandates
+ * these flags, with other compilers that can't take them, there will be
+ * trouble.
+ */
+   if (strstr(comps[NCOMP+DKC_], " -m32"))
+      fprintf(fpout, " -m32");
+   else if (strstr(comps[NCOMP+DKC_], " -m64"))
+      fprintf(fpout, " -m64");
    if (cdefs) fprintf(fpout, " %s", cdefs);
    if (THREADS)
    {
@@ -656,7 +716,7 @@ int main(int nargs, char **args)
          fprintf(fpout, "   %sFLAGS = %s\n",
                  COMPNAME[i], comps[NCOMP+i]);
    }
-   fprintf(fpout, "   F77NOOPT = -O0   # turn off optimization\n");
+   fprintf(fpout, "   F77NOOPT = $(F77FLAGS) -O0   # turn off optimization\n");
    fprintf(fpout, "   SMAFLAGS =");
    if (smaflags)
       fprintf(fpout, " %s", smaflags);
@@ -684,8 +744,6 @@ int main(int nargs, char **args)
    if (gccflags)
       fprintf(fpout, " %s", gccflags);
    GetGccVers(goodgcc, &i, &j, &k, &k);
-   if (OS == OSOSX && j > 3)  /* need bullshit apple annoyance flag */
-      fprintf(fpout, " -force_cpusubtype_ALL");
    if (OSIsWin(OS) && ptrbits != 64)  /* stop gcc breaking ABI */
       fprintf(fpout, " -mstackrealign");
    sp = GetPtrbitsFlag(OS, mach, ptrbits, goodgcc);
@@ -696,6 +754,7 @@ int main(int nargs, char **args)
          fprintf(fpout, " -fPIC");
    #endif
    fprintf(fpout, "\n");
+   fprintf(fpout, "   KC = $(DKC)\n   KCFLAGS = $(CDEFS) $(DKCFLAGS)\n");
 
    fprintf(fpout, "   LDFLAGS =");
    if (MachIsX86(mach))
@@ -712,10 +771,12 @@ int main(int nargs, char **args)
             fprintf(fpout, "_fbsd");
       }
    }
+   if (MachIsS390(mach))
+      fprintf(fpout, ptrbits == 32 ? "-m31" : "-m64");
    fprintf(fpout, "\n   F77SYSLIB = %s\n", f77lib ? f77lib : "");
-   fprintf(fpout, "   BC = $(ICC)\n");
-   fprintf(fpout, "   NCFLAGS = $(ICCFLAGS)\n");
-   fprintf(fpout, "\n   CLINKER = $(ICC)\n   CLINKFLAGS = $(ICCFLAGS)\n");
+   fprintf(fpout, "   BC = $(KC)\n");
+   fprintf(fpout, "   NCFLAGS = $(KCFLAGS)\n");
+   fprintf(fpout, "\n   CLINKER = $(KC)\n   CLINKFLAGS = $(KCFLAGS)\n");
    fprintf(fpout, "   FLINKER = $(F77)\n");
    if (strstr(comps[F77_], "mgwgfortran"))
       fprintf(fpout, "   FLINKFLAGS = $(F77FLAGS) -static\n");
@@ -724,7 +785,7 @@ int main(int nargs, char **args)
    fprintf(fpout, "   FCLINKFLAGS = $(FLINKFLAGS)");
    if (strstr(comps[F77_], "ifort") && !OSIsWin(OS))
       fprintf(fpout, " -nofor_main");
-   if (OS == OSWinNT && ptrbits == 64)
+   if (USEMINGW)
       fprintf(fpout, "\n   ARCHIVER = $(BLDdir)/mgwar\n");
    else
       fprintf(fpout, "\n   ARCHIVER = ar\n");
@@ -734,7 +795,7 @@ int main(int nargs, char **args)
  */
    if (OS == OSOSX)
       fprintf(fpout, "   RANLIB   = ranlib\n\n");
-   else if (OS == OSWinNT && ptrbits == 64)
+   else if (USEMINGW)
       fprintf(fpout, "   RANLIB   = $(BLDdir)/mgwranlib\n\n");
    else
       fprintf(fpout, "   RANLIB   = echo\n\n");
@@ -743,8 +804,8 @@ int main(int nargs, char **args)
    fprintf(fpout, "#  tar, gzip, gunzip, and parallel make\n");
    fprintf(fpout, "#  -------------------------------------\n");
    fprintf(fpout, "   TAR    = tar\n");
-   fprintf(fpout, "   GZIP   = gzip\n");
-   fprintf(fpout, "   GUNZIP = gunzip\n");
+   fprintf(fpout, "   BZIP   = bzip2\n");
+   fprintf(fpout, "   BUNZIP = bunzip2\n");
    fprintf(fpout, "   PMAKE  = %s\n\n", pmake ? pmake : "$(MAKE)");
 /*
  * Need to add libs to GetFlags and update GetSysLib to do this right
@@ -763,14 +824,13 @@ int main(int nargs, char **args)
    fprintf(fpout, "   SSLAPACKlib =  # set to serial system lapack\n");
    if (THREADS)
    {
-      fprintf(fpout, "   LIBS = -lpthread");
-      if (OSIsWin(OS) && ptrbits == 32)
-         fprintf(fpout, " -lkernel32");
+      if (OSIsWin(OS))
+         fprintf(fpout, "   LIBS = -lkernel32 -lm\n\n");
+      else
+         fprintf(fpout, "   LIBS = -lpthread -lm\n\n");
    }
    else
-      fprintf(fpout, "   LIBS =");
-   fprintf(fpout, " -lm");
-   fprintf(fpout, "\n\n");
+      fprintf(fpout, "   LIBS = -lm\n\n");
 
    fprintf(fpout,
    "#  --------------------------------------------------------------------\n");
