@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.10.1
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  *                    (C) Copyright 1998 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -199,7 +199,7 @@ void ATL_mprintf(int np, ...)
          vsprintf(ln, form, argptr);
          assert(strlen(ln) < 1024);/* sanity test only, will not stop overrun */
          va_end(argptr);
-         for (i=0; i < np; i++) if (fp[i]) fprintf(fp[i], ln);
+         for (i=0; i < np; i++) if (fp[i]) fprintf(fp[i], "%s", ln);
       #else
          for (i=0; i < np; i++) if (fp[i]) vfprintf(fp[i], form, argptr);
          va_end(argptr);
@@ -221,6 +221,20 @@ int GetFirstInt(char *ln)
    return(iret);
 }
 
+int GetFirstHex(char *ln)
+{
+   int i, iret=0;
+   for (i=0; ln[i]; i++)
+   {
+      if (isxdigit(ln[i]))
+      {
+         sscanf(ln+i, "%x", &iret);
+         break;
+      }
+   }
+   return(iret);
+}
+
 long long GetFirstLong(char *ln)
 {
    int i;
@@ -229,7 +243,21 @@ long long GetFirstLong(char *ln)
    {
       if (isdigit(ln[i]))
       {
-         sscanf(ln+i, "%ld", &iret);
+         sscanf(ln+i, "%Ld", &iret);
+         break;
+      }
+   }
+   return(iret);
+}
+long long GetFirstLongHex(char *ln)
+{
+   int i;
+   long long iret=0;
+   for (i=0; ln[i]; i++)
+   {
+      if (isxdigit(ln[i]))
+      {
+         sscanf(ln+i, "%lx", &iret);
          break;
       }
    }
@@ -268,6 +296,19 @@ int GetLastInt(char *ln)
    }
    return(iret);
 }
+int GetLastHex(char *ln)
+{
+   int i, iret=0;
+   for (i=0; ln[i]; i++);
+   if (i > 0) for (i--; i > 0 && !isxdigit(ln[i]); i--);
+   if (i > 0 || (i == 0 && isxdigit(ln[0])))
+   {
+      while(isxdigit(ln[i]) && i > 0) i--;
+      if (!isxdigit(ln[i])) i++;
+      sscanf(ln+i, "%x", &iret);
+   }
+   return(iret);
+}
 
 long long GetLastLong(char *ln)
 {
@@ -283,6 +324,47 @@ long long GetLastLong(char *ln)
    }
    return(iret);
 }
+long long GetLastLongHex(char *ln)
+{
+   int i;
+   long iret=0;
+   for (i=0; ln[i]; i++);
+   if (i > 0) for (i--; i > 0 && !isxdigit(ln[i]); i--);
+   if (i > 0 || (i == 0 && isxdigit(ln[0])))
+   {
+      while(isxdigit(ln[i]) && i > 0) i--;
+      if (!isxdigit(ln[i])) i++;
+      sscanf(ln+i, "%lx", &iret);
+   }
+   return(iret);
+}
+
+long long GetLastLongWithRound(char *ln)
+/*
+ * Gets a long from end of line, assuming the line may be in decimal
+ * format.  If given 1.6 it will return 2.  However, if given 1e256,
+ * it will return 256!
+ */
+{
+   int i;
+   long iret=0;
+   for (i=0; ln[i]; i++);
+   if (i > 0)
+   {
+      for (i--; i > 0 && !isdigit(ln[i]); i--);
+      if (i > 0 && ln[i] == '.')  /* allow skip of 1 decimal point */
+         for (i--; i > 0 && !isdigit(ln[i]); i--);
+   }
+   if (i > 0 || (i == 0 && (isdigit(ln[0]) || ln[0] == '.')))
+   {
+      double d;
+      while(isdigit(ln[i]) && i > 0) i--;
+      if (!isdigit(ln[i])) i++;
+      sscanf(ln+i, "%lf", &d);
+      iret = (int)(d+0.5);
+   }
+   return(iret);
+}
 
 char *ATL_fgetln(FILE *fpin)
 /*
