@@ -56,13 +56,14 @@ enum MACHTYPE ProbeArch()
    enum ARCHFAM fam;
    enum MACHTYPE mach=MACHOther;
    int ierr, i;
-   char res[1024];
+   char *res;
 
    fam = ProbeArchFam(NULL);
    switch(fam)
    {
    case AFPPC: /* don't know */
-      if (!CmndOneLine(NULL, "/usr/sbin/prtconf | fgrep 'Processor Type'", res))
+      res = atlsys_1L(NULL, "/usr/sbin/prtconf | fgrep 'Processor Type'", 0, 0);
+      if (res)
       {
          if (strstr(res, "PowerPC_POWER5"))
             mach = IbmPwr5;
@@ -72,35 +73,34 @@ enum MACHTYPE ProbeArch()
             mach = IbmPwr6;
          else if (strstr(res, "PowerPC_POWER4"))
             mach = IbmPwr4;
+         free(res);
       }
       break;
    }
    return(mach);
 }
-
 int ProbeNCPU()
 {
    int ncpu = 0;
-   char *reslns, res[1024];
+   char *res;
 
-   if (!CmndOneLine(NULL, "/usr/sbin/prtconf | fgrep 'Number Of Processors'",
-                    res))
+   res = atlsys_1L(NULL, "/usr/sbin/prtconf | fgrep 'Number Of Processors'",
+                   0, 0);
+   if (res)
+   {
       ncpu = GetLastInt(res);
+      free(res);
+   }
    return(ncpu);
 }
 
 int ProbePointerBits(int *sure)
 {
-   int iret = 32;
+   int i;
    char *uname;
-   char cmnd[1024], res[1024];
+   char *cmnd, *res;
 
    *sure = 0;
-/*
- * Note this is a weak probe, archinfo_x86 much better . . .
- */
-   uname = FindUname(NULL);
-   sprintf(cmnd, "%s -a", uname);
 /*
  * This probe should be running on backend; if its ptr length is 8, we've
  * definitely got a 64 bit machine
@@ -109,19 +109,33 @@ int ProbePointerBits(int *sure)
  */
    if (sizeof(void*) == 8)
    {
-      iret = 64;
       *sure = 1;
+      return(64);
    }
 
-   else if (!CmndOneLine(NULL, "/usr/sbin/prtconf | fgrep 'Kernel Type'", res))
+   res = atlsys_1L(NULL, "/usr/sbin/prtconf | fgrep 'Kernel Type'", 0, 0);
+   if (res)
    {
       if (GetLastInt(res) == 64)
       {
-         iret = 64;
          *sure = 1;
+         free(res);
+         return(64);
       }
+      free(res);
    }
-   else if (!CmndOneLine(NULL, cmnd, res))
+/*
+ * Note this is a weak probe, archinfo_x86 much better . . .
+ */
+   uname = FindUname(NULL);
+   i = strlen(uname) + 4;
+   cmnd = malloc(sizeof(char)*i);
+   assert(cmnd);
+   sprintf(cmnd, "%s -a", uname);
+
+   res = atlsys_1L(NULL, cmnd, 0, 0);
+   free(cmnd);
+   if (res)
    {
 /*
  *    If uname is a known 64-bit platform, we're sure we've got OS support
@@ -129,20 +143,26 @@ int ProbePointerBits(int *sure)
  */
       if (strstr(res, "x86_64") || strstr(res, "ppc64") || strstr(res, "ia64"))
       {
-         iret = 64;
          *sure = 1;
+         free(res);
+         return(64);
       }
+      free(res);
    }
-   return(iret);
+   return(32);
 }
 
 int ProbeMhz()
 {
    int mhz=0;
-   char res[1024];
-   if (!CmndOneLine(NULL, "/usr/sbin/prtconf | fgrep 'Processor Clock Speed'",
-                    res))
+   char *res;
+   res = atlsys_1L(NULL, "/usr/sbin/prtconf | fgrep 'Processor Clock Speed'",
+                   0, 0);
+   if (res)
+   {
       mhz = GetLastInt(res);  /* assumes clock speed always given in MHz */
+      free(res);
+   }
    return(mhz);
 }
 
