@@ -446,6 +446,10 @@ COMPNODE **GetDefaultComps(enum OSTYPE OS, enum MACHTYPE arch, int verb,
 
    if ((vecexts & (1<<ISA_AVXFMA4)) && arch == AmdDozer)
       vp = "-msse4.2 -mfma4";
+   else if ((vecexts & (1<<ISA_AVXMAC)) && arch == AmdDriver)
+      vp = "-mavx -mno-sse2avx -mfma";
+   else if ((vecexts & (1<<ISA_AVXMAC)))
+      vp = "-mavx2 -mfma";
    else if (vecexts & (1<<ISA_VSX))
       vp = "-mvsx";
    else if (vecexts & (1<<ISA_AV))
@@ -608,11 +612,11 @@ char *GetPtrbitsFlag(enum OSTYPE OS, enum MACHTYPE arch, int ptrbits,
    else if (OS == OSAIX)
       sp = (ptrbits == 64) ? "-maix64" : "-maix32";
    else if ((MachIsX86(arch) || MachIsPPC(arch) || MachIsUS(arch)) ||
-            arch == IbmPwr7 || arch == IbmPwr6)
+            arch == IbmPwr7 || arch == IbmPwr6 || arch == Pwre6500)
    {
       if (ptrbits == 64)
          sp = "-m64";
-       else if (ptrbits == 32)
+      else if (ptrbits == 32)
          sp = "-m32";
    }
    return(sp);
@@ -1232,6 +1236,7 @@ void GetBestGccVers(enum OSTYPE OS, enum MACHTYPE arch,
    case IntCore2:
    case IntCorei1:
    case IntCorei2:
+   case IntCorei3:
    case Amd64K10h:
    case ARMv7:
    default:
