@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  *                    (C) Copyright 1998 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -220,7 +220,7 @@ void ATL_mprintf(int np, ...)
          vsprintf(ln, form, argptr);
          assert(strlen(ln) < 1024);/* sanity test only, will not stop overrun */
          va_end(argptr);
-         for (i=0; i < np; i++) if (fp[i]) fprintf(fp[i], ln);
+         for (i=0; i < np; i++) if (fp[i]) fprintf(fp[i], "%s", ln);
       #else
          for (i=0; i < np; i++) if (fp[i]) vfprintf(fp[i], form, argptr);
          va_end(argptr);
@@ -242,6 +242,20 @@ int GetFirstInt(char *ln)
    return(iret);
 }
 
+int GetFirstHex(char *ln)
+{
+   int i, iret=0;
+   for (i=0; ln[i]; i++)
+   {
+      if (isxdigit(ln[i]))
+      {
+         sscanf(ln+i, "%x", &iret);
+         break;
+      }
+   }
+   return(iret);
+}
+
 long long GetFirstLong(char *ln)
 {
    int i;
@@ -250,7 +264,21 @@ long long GetFirstLong(char *ln)
    {
       if (isdigit(ln[i]))
       {
-         sscanf(ln+i, "%ld", &iret);
+         sscanf(ln+i, "%Ld", &iret);
+         break;
+      }
+   }
+   return(iret);
+}
+long long GetFirstLongHex(char *ln)
+{
+   int i;
+   long long iret=0;
+   for (i=0; ln[i]; i++)
+   {
+      if (isxdigit(ln[i]))
+      {
+         sscanf(ln+i, "%lx", &iret);
          break;
       }
    }
@@ -289,6 +317,19 @@ int GetLastInt(char *ln)
    }
    return(iret);
 }
+int GetLastHex(char *ln)
+{
+   int i, iret=0;
+   for (i=0; ln[i]; i++);
+   if (i > 0) for (i--; i > 0 && !isxdigit(ln[i]); i--);
+   if (i > 0 || (i == 0 && isxdigit(ln[0])))
+   {
+      while(isxdigit(ln[i]) && i > 0) i--;
+      if (!isxdigit(ln[i])) i++;
+      sscanf(ln+i, "%x", &iret);
+   }
+   return(iret);
+}
 
 long long GetLastLong(char *ln)
 {
@@ -304,6 +345,47 @@ long long GetLastLong(char *ln)
    }
    return(iret);
 }
+long long GetLastLongHex(char *ln)
+{
+   int i;
+   long iret=0;
+   for (i=0; ln[i]; i++);
+   if (i > 0) for (i--; i > 0 && !isxdigit(ln[i]); i--);
+   if (i > 0 || (i == 0 && isxdigit(ln[0])))
+   {
+      while(isxdigit(ln[i]) && i > 0) i--;
+      if (!isxdigit(ln[i])) i++;
+      sscanf(ln+i, "%lx", &iret);
+   }
+   return(iret);
+}
+
+long long GetLastLongWithRound(char *ln)
+/*
+ * Gets a long from end of line, assuming the line may be in decimal
+ * format.  If given 1.6 it will return 2.  However, if given 1e256,
+ * it will return 256!
+ */
+{
+   int i;
+   long iret=0;
+   for (i=0; ln[i]; i++);
+   if (i > 0)
+   {
+      for (i--; i > 0 && !isdigit(ln[i]); i--);
+      if (i > 0 && ln[i] == '.')  /* allow skip of 1 decimal point */
+         for (i--; i > 0 && !isdigit(ln[i]); i--);
+   }
+   if (i > 0 || (i == 0 && (isdigit(ln[0]) || ln[0] == '.')))
+   {
+      double d;
+      while(isdigit(ln[i]) && i > 0) i--;
+      if (!isdigit(ln[i])) i++;
+      sscanf(ln+i, "%lf", &d);
+      iret = (int)(d+0.5);
+   }
+   return(iret);
+}
 
 void PrintBanner(char *fnam, int START, int sec, int subsec, int subsubsec);
 static void ATL_Cassert0(size_t cond, char *exp, char *logfile, int line)
@@ -362,10 +444,10 @@ void PrintBanner(char *fnam, int START, int sec, int subsec, int subsubsec)
    GetDate(&month, &day, &year, &hour, &min);
    fprintf(fp, "\n%s%s%s", sep, sep, sep);
    if (START)
-      fprintf(fp, "*       BEGAN ATLAS3.9.51 INSTALL OF SECTION %1d-%1d-%1d ON %02d/%02d/%04d AT %02d:%02d     *\n",
+      fprintf(fp, "*       BEGAN ATLAS3.10.2 INSTALL OF SECTION %1d-%1d-%1d ON %02d/%02d/%04d AT %02d:%02d     *\n",
               sec, subsec, subsubsec, month, day, year, hour, min);
    else
-      fprintf(fp, "*      FINISHED ATLAS3.9.51 INSTALL OF SECTION %1d-%1d-%1d ON %02d/%02d/%04d AT %02d:%02d   *\n",
+      fprintf(fp, "*      FINISHED ATLAS3.10.2 INSTALL OF SECTION %1d-%1d-%1d ON %02d/%02d/%04d AT %02d:%02d   *\n",
                       sec, subsec, subsubsec, month, day, year, hour, min);
    fprintf(fp, "%s%s%s\n\n\n", sep, sep, sep);
    fclose(fp);
@@ -486,7 +568,7 @@ void GetMMRES(char pre, int *muladd, int *lat, int *nb, int *pref,
 }
 
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Code contributers : R. Clint Whaley, Antoine P. Petitet
@@ -738,7 +820,8 @@ void GoToTown(int ARCHDEF, int L1DEF, int TuneLA)
          mmmf = mmp->mflop[0];
          ATL_mprintf(2, fpsum, stdout,
 "      %cL1MATMUL: lat=%d, nb=%d, pf=%d, mu=%d, nu=%d, ku=%d, if=%d, nf=%d;\n",
-                 pre, lat, nb, pfA, mu, nu, ku, ifetch, nfetch);
+                     pre, mmp->lat, nb, mmp->pref, mmp->mu, mmp->nu, mmp->ku,
+                     mmp->iftch, mmp->nftch);
          ATL_mprintf(2, fpsum, stdout,
             "                 Performance: %.2f (%5.2f percent of %s)\n",
                      mmmf, (mmmf/mfp)*100.0, peakstr);
@@ -1074,7 +1157,11 @@ void GoToTown(int ARCHDEF, int L1DEF, int TuneLA)
    PrintStartStop(stdout, fpsum, 3, 1, 5, 1, 0, "FINAL STATIC LIBRARY UPDATE");
    sprintf(ln2, "INSTALL_LOG/LIBUPDATE.LOG");
    PrintBanner(ln2, 1, 5, 1, 1);
-   sprintf(ln, "%s IBuildLibs IBuildPtlibs0 %s %s\n", fmake, redir, ln2);
+   #if defined(ATL_NCPU) && ATL_NCPU > 1
+      sprintf(ln, "%s IBuildLibs IBuildPtlibs0 %s %s\n", fmake, redir, ln2);
+   #else
+      sprintf(ln, "%s IBuildLibs %s %s\n", fmake, redir, ln2);
+   #endif
    fprintf(stdout, ln);
    ATL_Cassert(system(ln)==0, "STATIC LIBRARY UPDATE", ln2);
    PrintBanner(ln2, 0, 5, 1, 1);
