@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  * Copyright (C) 2009 Siju Samuel
  *
  * Code contributers : Siju Samuel, R. Clint Whaley, Anthony M. Castaldo
@@ -1414,7 +1414,12 @@ int RunCases(TYPE thresh, int flushKB, int ldagap, int *NREPS,
          }
       }
    }
-   printf("\n%d cases ran, %d cases passed\n\n", ntest, npass);
+   if (ntest == npass)
+      printf("\n%d cases ran, %d cases passed\n\n", ntest, npass);
+   else
+      printf("\n%d cases ran, %d cases failed, %d cases passed\n\n", ntest,
+             ntest-npass, npass);
+
    return(ntest-npass);
 }
 
