@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,7 +40,7 @@
 static void ATL_gemoveT_aX(ATL_CINT N, ATL_CINT M, const SCALAR alpha,
                            const TYPE *A, ATL_CINT lda, TYPE *C, ATL_CINT ldc)
 {
-   ATL_CINT incA = lda+lda;
+   size_t incA = lda+lda;
    ATL_INT i;
 
    for (i=0; i < N; i++, A += incA, C += 2)
@@ -55,7 +55,8 @@ static void ATL_gemoveT_a1(ATL_CINT N, ATL_CINT M, const SCALAR alpha,
                            const TYPE *A, ATL_CINT lda, TYPE *C, ATL_CINT ldc)
 {
    ATL_INT i, j;
-   ATL_CINT incA = lda - M, incC = 1 - ldc*M;
+   ATL_CINT incA = lda - M;
+   size_t incC = 1 - ldc*M;
 
    for (j=N; j; j--, A += incA, C += incC)
       for (i=M; i; i--, C += ldc)
@@ -65,7 +66,8 @@ static void ATL_gemoveT_an1(ATL_CINT N, ATL_CINT M, const SCALAR alpha,
                             const TYPE *A, ATL_CINT lda, TYPE *C, ATL_CINT ldc)
 {
    ATL_INT i, j;
-   ATL_CINT incA = lda - M, incC = 1 - ldc*M;
+   ATL_CINT incA = lda - M;
+   size_t incC = 1 - ldc*M;
 
    for (j=N; j; j--, A += incA, C += incC)
       for (i=M; i; i--, C += ldc)
