@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  *                    (C) Copyright 1999 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -197,16 +197,17 @@ typedef void (*MMPTR)
 int Mjoin(PATL,NCmmJIK)
    (const enum ATLAS_TRANS TA, const enum ATLAS_TRANS TB,
     const int M, const int N, const int K, const SCALAR alpha,
-    const TYPE *A, const int lda, const TYPE *B, const int ldb,
-    const SCALAR beta, TYPE *C, const int ldc)
+    const TYPE *A, const int lda0, const TYPE *B, const int ldb0,
+    const SCALAR beta, TYPE *C, const int ldc0)
 /*
  * JIK loop-ordered matmul with no matrix copy
  */
 {
+   const size_t lda=lda0, ldb=ldb0, ldc=ldc0;
+   size_t incAk, incAm, incAn, incBk, incBm, incBn;
    const int Mb = M / MB, Nb = N / NB, Kb = K / KB;
    const int mr = M - Mb*MB, nr = N - Nb*NB, kr = K - Kb*KB;
-   int incAk, incAm, incAn, incBk, incBm, incBn;
-   const int incCm = (MB<<1), incCn = (ldc*NB - M + mr)<<1;
+   const size_t incCm = (MB<<1), incCn = (ldc*NB - M + mr)<<1;
    int i, j, k;
    const TYPE *a=A, *b=B;
    const TYPE ralpha = *alpha, rbeta = *beta;
