@@ -181,7 +181,7 @@ void ATL_USERMM(const int M, const int N, const int K, const TYPE alpha,
 	.globl  Mjoin(_,ATL_USERMM)
 Mjoin(_,ATL_USERMM):
 #else
-   #if defined(ATL_USE64BITS)
+   #if defined(ATL_USE64BITS) && _CALL_ELF != 2
 /*
  *      Official Program Descripter section, seg fault w/o it on Linux/PPC64
  */
@@ -1321,7 +1321,7 @@ MLOOPU:
    #endif
 	vmaddfp	vC01, vA0, vB1, vC01
    #ifdef BETAX
-	dcbtst	0, pBETA, 0
+	dcbtst	0, pBETA
    #endif
 	vmaddfp	vC11, vA1, vB1, vC11
 	vmaddfp	vC21, vA2, vB1, vC21
