@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  *                    (C) Copyright 2004 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,6 +40,10 @@
 #ifndef ATL_GAS_x8632
    #error "This kernel requires gas x86-32 assembler!"
 #endif
+#ifndef ATL_SSE2
+   #error "This routine requires SSE2!"
+#endif
+
 /*
 #if KB != 60
    #error "KB must be 60!"
