@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  * Copyright (C) 2011 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,10 @@
 #if !defined(ATL_GAS_x8664)
    #error "This kernel requires x86-64 assembly!"
 #endif
+#ifndef ATL_AVX
+   #error "This routine requires AVX!"
+#endif
+
 
 #if !defined(KB) || (KB == 0)
    #error "KB must be a compile-time constant!"
