@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  *                   (C) Copyright 2000 Peter Soendergaard
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,6 +28,9 @@
  *
  */
 
+#ifndef ATL_SSE1
+   #error "This routine requires SSE1!"
+#endif
 #define SSE
 #include "SSE3Dnow.h"
 #include "atlas_misc.h"
