@@ -1,5 +1,5 @@
 /*
- *             Automatically Tuned Linear Algebra Software v3.9.51
+ *             Automatically Tuned Linear Algebra Software v3.10.2
  * Copyright (C) 2010, 2009 R. Clint Whaley
  *
  * Redistribution and use in source and binary forms, with or without
@@ -60,7 +60,7 @@ struct FA_allocs *NewAlloc(size_t size, struct FA_allocs *next,
    int n, i;
    const int malign = align >= misalign ? align : misalign;
 
-   n = size + align + malign;
+   n = size + align + align + malign;
    i = (n >> 3)<<3;
    if (n != i)
       n += n - i;
@@ -74,12 +74,13 @@ struct FA_allocs *NewAlloc(size_t size, struct FA_allocs *next,
    ap->memA = align ? (void*) ((((size_t) cp)/align)*align + align) : cp;
 /*
  * Misalign to misalign
+ * We often need to make sure to unaligned addresses share the same modulo
+ * so that they have the *same* degree of misalignment (so that their alignment
+ * can be fixed by simple peeling), and so in this case force the address
+ * modulo the misalign to be the exact align value.
  */
    if (misalign)
-   {
-      if (((size_t)ap->memA)%misalign == 0)
-         ap->memA = ((char*)ap->memA) + align;
-   }
+      ap->memA = (void*)((((size_t)ap->memA)/malign)*malign + malign + align);
    ap->next = next;
    return(ap);
 }
@@ -226,7 +227,7 @@ static double mysum(ATL_CINT N, double *d)
 double r2time(
    int verb,            /* verbosity */
    int nreps,           /* number of reps to do for one timing sample */
-   ATL_INT flushelts,   /* size of area to flush to avoid cache reuse */
+   size_t flushelts,    /* size of area to flush to avoid cache reuse */
    ATL_INT M,           /* # of rows of array A */
    ATL_INT N,           /* # of cols of array A */
    TYPE *alpha,
@@ -351,11 +352,19 @@ double r2time(
  * through memory; mem starts with maxalign-aligned memory, so that we can
  * guarantee all further alignments
  */
-   maxalign = (MAx >= MAa) ? MAx : MAa;
-   maxalign = (maxalign >= MAy) ? maxalign : MAy;
-   maxalign = (maxalign >= FAy) ? maxalign : FAy;
-   maxalign = (maxalign >= FAx) ? maxalign : FAx;
-   maxalign = (maxalign >= FAa) ? maxalign : FAa;
+   maxalign = (MAx) ? MAx : 1;
+   if (MAy)
+      maxalign = ATL_lcm(MAy,maxalign);
+   if (MAa)
+      maxalign = ATL_lcm(MAa,maxalign);
+   if (FAx)
+      maxalign = ATL_lcm(FAx,maxalign);
+   if (FAy)
+      maxalign = ATL_lcm(FAy,maxalign);
+   if (FAa)
+      maxalign = ATL_lcm(FAa,maxalign);
+   if (maxalign == 1)
+      maxalign = 0;
    j = (FAx) ? FAx : sizeof(TYPE);
    if (MAx)
       for (i=0; (i % j != 0 || i%MAx == 0); i += sizeof(TYPE));
@@ -463,7 +472,7 @@ double r2time(
 }
 #endif
 
-void DoTimes(int verb, ATL_INT flshelts, ATL_INT ntim, ATL_INT nrep,
+void DoTimes(int verb, size_t flshelts, ATL_INT ntim, ATL_INT nrep,
              ATL_INT mu, ATL_INT nu, ATL_INT M, ATL_INT N, TYPE *alpha,
              ATL_INT lda, int FAa, int MAa, int FAx, int MAx, int FAy, int MAy)
 {
@@ -530,7 +539,7 @@ void PrintUsage(char *name, char *arg, int i)
 }
 
 void GetFlags(int nargs, char **args, int *verb,
-              ATL_INT *flushelts, ATL_INT *celts, ATL_INT *pgelts,
+              size_t *flushelts, ATL_INT *celts, ATL_INT *pgelts,
               ATL_INT *mu, ATL_INT *nu, ATL_INT *ntim, ATL_INT *nrep,
               enum ATLAS_TRANS *TA, ATL_INT *m, ATL_INT *n, ATL_INT *lda,
               TYPE *beta,
@@ -538,6 +547,7 @@ void GetFlags(int nargs, char **args, int *verb,
 {
    double mfF=ATL_nkflop/1000.0, flops;
    ATL_INT j, h;
+   size_t il;
    int i;
    char ch;
 
@@ -602,9 +612,9 @@ void GetFlags(int nargs, char **args, int *verb,
       case 'C' :  /* set flushsz in KB */
          if (++i >= nargs)
             PrintUsage(args[0], "out of flags in -C ", i-1);
-         j = atoi(args[i]);
-         if (j >= 0)
-            *flushelts = j*ATL_DivBySize(1024);
+         il = atol(args[i]);
+         if (il >= 0)
+            *flushelts = il*ATL_DivBySize(1024);
          break;
       case 'p' :  /* set pagesz in KB */
          if (++i >= nargs)
@@ -709,7 +719,8 @@ void GetFlags(int nargs, char **args, int *verb,
 }
 int main(int nargs, char **args)
 {
-   ATL_INT flushelts, celts, pgelts, mu, nu, ntim, nrep, m, n, lda;
+   size_t flushelts;
+   ATL_INT celts, pgelts, mu, nu, ntim, nrep, m, n, lda;
    int FAa, MAa, FAx, MAx, FAy, MAy;    /* Force & Max align for ops */
    int verb;
    enum ATLAS_TRANS TA;
