@@ -4,6 +4,6 @@ TYPE ATL_UDOT(const int N, const TYPE *X, const int incX,
 {
    register TYPE dot=ATL_rzero;
    int i;
-   for (i=0; i != N; i++) dot += X[i] * Y[i];
+   for (i=0; i < N; i++) dot += X[i] * Y[i];
    return(dot);
 }
